OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie można zapisać do katalogu \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ale jeśli wolisz, aby plik config.php był tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true.",
    "See %s" : "Zobacz %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikacja %1$s nie jest dostępna lub ma wersję niekompatybilną z tym serwerem. Sprawdź katalog aplikacji.",
    "Sample configuration detected" : "Wykryto przykładową konfigurację",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Wykryto, że przykładowa konfiguracja została skopiowana. Może to spowodować przerwanie instalacji, która nie jest wspierana. Przeczytaj dokumentację przed dokonaniem zmian w pliku config.php",
    "The page could not be found on the server." : "Nie znaleziono strony na serwerze.",
    "%s email verification" : "Weryfikacja adresu e-mail %s",
    "Email verification" : "Weryfikacja adresu e-mail",
    "Click the following button to confirm your email." : "Kliknij poniższy przycisk, aby potwierdzić swój adres e-mail.",
    "Click the following link to confirm your email." : "Kliknij poniższy link, aby potwierdzić swój adres e-mail.",
    "Confirm your email" : "Potwierdź swój adres e-mail",
    "Other activities" : "Inne aktywności",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education bundle" : "Pakiet edukacyjny",
    "Enterprise bundle" : "Pakiet dla firm",
    "Groupware bundle" : "Pakiet do pracy grupowej",
    "Hub bundle" : "Pakiet centralny",
    "Public sector bundle" : "Pakiet sektora publicznego",
    "Social sharing bundle" : "Pakiet udostępniania społecznościowego",
    "PHP %s or higher is required." : "Wymagane jest PHP %s lub wyższe.",
    "PHP with a version lower than %s is required." : "Wymagane jest PHP z wersją niższą niż %s.",
    "%sbit or higher PHP required." : "%sbit lub wymagane wyższe PHP.",
    "The following architectures are supported: %s" : "Obsługiwane są następujące architektury: %s",
    "The following databases are supported: %s" : "Obsługiwane są następujące bazy danych: %s",
    "The command line tool %s could not be found" : "Nie można znaleźć narzędzia wiersza poleceń %s",
    "The library %s is not available." : "Biblioteka %s nie jest dostępna.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Wymagana jest biblioteka %1$s z wersją wyższą niż %2$s - dostępna wersja %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Wymagana jest biblioteka %1$s w wersji niższej niż %2$s - dostępna wersja %3$s.",
    "The following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
    "Server version %s or higher is required." : "Wymagana jest wersja serwera %s lub wyższa.",
    "Server version %s or lower is required." : "Wymagana jest wersja serwera %s lub niższa.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowane konto musi być administratorem, subadministratorem lub posiadać specjalne uprawnienia, aby uzyskać dostęp do tego ustawienia",
    "Logged in account must be an admin or sub admin" : "Zalogowane konto musi być administratorem lub subadministratorem",
    "Logged in account must be an admin" : "Zalogowane konto musi być administratorem",
    "Wiping of device %s has started" : "Rozpoczęto czyszczenie urządzenia %s",
    "Wiping of device »%s« has started" : "Rozpoczęto czyszczenie urządzenia »%s«",
    "»%s« started remote wipe" : "»%s« rozpoczęło zdalne czyszczenie",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Urządzenie lub aplikacja »%s« uruchomiło proces zdalnego czyszczenia. Otrzymasz kolejny e-mail po zakończeniu procesu",
    "Wiping of device %s has finished" : "Zakończono czyszczenie urządzenia %s",
    "Wiping of device »%s« has finished" : "Zakończono czyszczenie urządzenia »%s«",
    "»%s« finished remote wipe" : "»%s« zakończył zdalne czyszczenie",
    "Device or application »%s« has finished the remote wipe process." : "Urządzenie lub aplikacja »%s« zakończyło proces zdalnego czyszczenia.",
    "Remote wipe started" : "Rozpoczęto zdalne czyszczenie",
    "A remote wipe was started on device %s" : "Zdalne czyszczenie zostało uruchomione na urządzeniu %s",
    "Remote wipe finished" : "Zdalne czyszczenie zakończone",
    "The remote wipe on %s has finished" : "Zakończono zdalne czyszczenie na %s",
    "Authentication" : "Uwierzytelnienie",
    "Unknown filetype" : "Nieznany typ pliku",
    "Invalid image" : "Nieprawidłowy obraz",
    "Avatar image is not square" : "Obraz awatara nie jest kwadratowy",
    "Files" : "Pliki",
    "View profile" : "Zobacz profil",
    "_%nh_::_%nh_" : ["%nh","%nh","%nh","%ngodz."],
    "Local time: %s" : "Czas lokalny: %s",
    "today" : "dzisiaj",
    "tomorrow" : "jutro",
    "yesterday" : "wczoraj",
    "_in %n day_::_in %n days_" : ["za %n dzień","za %n dni","za %n dni","za %n dni"],
    "_%n day ago_::_%n days ago_" : ["%n dzień temu","%n dni temu","%n dni temu","%n dni temu"],
    "next month" : "następny miesiąc",
    "last month" : "w zeszłym miesiącu",
    "_in %n month_::_in %n months_" : ["za %n miesiąc","za %n miesiące","za %n miesięcy","za %n miesięcy"],
    "_%n month ago_::_%n months ago_" : ["%n miesiąc temu","%n miesiące temu","%n miesięcy temu","%n miesięcy temu"],
    "next year" : "następny rok",
    "last year" : "w zeszłym roku",
    "_in %n year_::_in %n years_" : ["za %n rok","za %n lata","za %n lat","za %n lat"],
    "_%n year ago_::_%n years ago_" : ["%n rok temu","%n lata temu","%n lat temu","%n lat temu"],
    "_in %n hour_::_in %n hours_" : ["za %n godzinę","za %n godziny","za %n godzin","za %n godzin"],
    "_%n hour ago_::_%n hours ago_" : ["%n godzina temu","%n godziny temu","%n godzin temu","%n godzin temu"],
    "_in %n minute_::_in %n minutes_" : ["za %n minutę","za %n minuty","za %n minut","za %n minut"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuta temu","%n minuty temu","%n minut temu","%n minut temu"],
    "in a few seconds" : "za kilka sekund",
    "seconds ago" : "przed chwilą",
    "Empty file" : "Pusty plik",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduł o ID: %s nie istnieje. Włącz go w ustawieniach aplikacji lub skontaktuj się z administratorem.",
    "Dot files are not allowed" : "Pliki z kropką są niedozwolone",
    "%1$s (renamed)" : "%1$s (zmieniona nazwa)",
    "renamed file" : "zmieniona nazwa pliku",
    "Invalid parent path" : "Nieprawidłowa ścieżka nadrzędna",
    "File already exists" : "Plik już istnieje",
    "Invalid path" : "Niewłaściwa ścieżka",
    "Failed to create file from template" : "Nie udało się utworzyć pliku z szablonu",
    "Templates" : "Szablony",
    "Path contains invalid segments" : "Ścieżka zawiera nieprawidłowe segmenty",
    "Filename is a reserved word" : "Nazwa pliku jest słowem zastrzeżonym",
    "Filename contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
    "Filename is too long" : "Nazwa pliku jest za długa",
    "Empty filename is not allowed" : "Pusta nazwa pliku jest niedozwolona",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie można odczytać pliku appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikacji \"%s\" nie można zainstalować, ponieważ nie jest kompatybilna z tą wersją serwera.",
    "__language_name__" : "Polski",
    "This is an automatically sent email, please do not reply." : "Jest to wiadomość e-mail wysłana automatycznie, prosimy nie odpowiadać na nią.",
    "Help & privacy" : "Pomoc i prywatność",
    "Appearance and accessibility" : "Wygląd i dostępność",
    "Apps" : "Aplikacje",
    "Personal settings" : "Ustawienia osobiste",
    "Administration settings" : "Ustawienia administracyjne",
    "Settings" : "Ustawienia",
    "Log out" : "Wyloguj",
    "Accounts" : "Konta",
    "Email" : "E-mail",
    "Mail %s" : "Poczta %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Zobacz %s w Fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Połącz %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Zobacz %s na Twitterze",
    "Website" : "Strona internetowa",
    "Visit %s" : "Odwiedź %s",
    "Address" : "Adres",
    "Profile picture" : "Zdjęcie profilowe",
    "About" : "Informacje",
    "Display name" : "Wyświetlana nazwa",
    "Headline" : "Nagłówek",
    "Organisation" : "Organizacja",
    "Role" : "Rola społeczna",
    "Pronouns" : "Zaimki",
    "Unknown account" : "Nieznane konto",
    "Additional settings" : "Ustawienia dodatkowe",
    "Enter the database Login and name for %s" : "Wprowadź login i nazwę bazy danych dla %s",
    "Enter the database Login for %s" : "Wpisz logowanie do bazy danych dla %s",
    "Enter the database name for %s" : "Podaj nazwę bazy danych dla %s",
    "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
    "You need to enter details of an existing account." : "Musisz wprowadzić szczegółowe dane dla istniejącego konta.",
    "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
    "Set an admin Login." : "Ustaw login administratora.",
    "Set an admin password." : "Ustaw hasło administratora.",
    "Cannot create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do udostępniania %s musi implementować interfejs OCP\\Share_Backend",
    "Sharing backend %s not found" : "Zaplecze %s do udostępniania nie zostało znalezione",
    "Sharing backend for %s not found" : "Zaplecze do udostępniania dla %s nie zostało znalezione",
    "%1$s shared %2$s with you" : "%1$s udostępnił %2$s Tobie",
    "Open %s" : "Otwórz %s",
    "%1$s via %2$s" : "%1$s przez %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s udostępnił Ci %2$s i chce dodać:",
    "%1$s shared %2$s with you and wants to add" : "%1$s udostępnił Ci %2$s i chce dodać",
    "%s added a note to a file shared with you" : "%s dodał notatkę do pliku udostępnionego Tobie",
    "Passwords are enforced for link and mail shares" : "Hasła są wymuszane w przypadku udostępniania łączy i poczty",
    "Share recipient is not a valid user" : "Odbiorca udostępnienia nie jest prawidłowym użytkownikiem",
    "Share recipient is not a valid group" : "Odbiorca udostępnienia nie jest prawidłową grupą",
    "Share recipient should be empty" : "Odbiorca udostępnienia powinien być pusty",
    "Share recipient should not be empty" : "Odbiorca udostępnienia nie powinien być pusty",
    "Share recipient is not a valid circle" : "Odbiorca udostępnienia nie jest prawidłowym kręgiem",
    "Unknown share type" : "Nieznany typ udostępnienia",
    "Cannot share with yourself" : "Nie można dzielić się ze sobą",
    "Shared path must be set" : "Należy ustawić ścieżkę współdzieloną",
    "Shared path must be either a file or a folder" : "Udostępniona ścieżka musi być plikiem lub katalogiem",
    "You cannot share your root folder" : "Nie możesz udostępnić swojego katalogu głównego root",
    "You are not allowed to share %s" : "Nie możesz udostępnić %s",
    "Valid permissions are required for sharing" : "Do udostępniania wymagane są ważne uprawnienia",
    "Cannot increase permissions of %s" : "Nie można zwiększyć uprawnień %s",
    "Shares need at least read permissions" : "Udostępnianie wymaga co najmniej uprawnień do odczytu",
    "Files cannot be shared with delete permissions" : "Pliki nie mogą zostać udostępnione z prawem do usuwania",
    "Files cannot be shared with create permissions" : "Pliki nie mogą zostać udostępnione z prawem do tworzenia",
    "Expiration date is in the past" : "Data ważności już minęła",
    "Expiration date is enforced" : "Obowiązuje data ważności",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie można utworzyć daty wygaśnięcia na %n dzień do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu"],
    "Sharing is only allowed with group members" : "Udostępnianie jest dozwolone tylko członkom grupy",
    "Group sharing is now allowed" : "Udostępnianie grupowe jest teraz dozwolone",
    "Sharing is only allowed within your own groups" : "Udostępnianie jest dozwolone wyłącznie w obrębie własnych grup",
    "Path is already shared with this group" : "Ścieżka jest już udostępniona tej grupie",
    "Link sharing is not allowed" : "Udostępnianie odnośników jest niedozwolone",
    "Public upload is not allowed" : "Przesyłanie publiczne nie jest dozwolone",
    "Sharing is disabled" : "Udostępnianie jest wyłączone",
    "Sharing is disabled for you" : "Udostępnianie jest dla Ciebie wyłączone",
    "Cannot share with the share owner" : "Nie można udostępnić właścicielowi udziału",
    "Share does not have a full ID" : "Udział nie ma pełnego identyfikatora",
    "Cannot change share type" : "Nie można zmienić typu udziału",
    "Can only update recipient on user shares" : "Może aktualizować odbiorców tylko w przypadku udziałów użytkownika",
    "Invalid share recipient" : "Nieprawidłowy odbiorca udostępnienia",
    "The requested share does not exist anymore" : "Żądane udostępnienie już nie istnieje",
    "The requested share comes from a disabled user" : "Żądane udostępnienie pochodzi od wyłączonego użytkownika",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Użytkownik nie został utworzony, ponieważ osiągnięto limit użytkowników. Sprawdź swoje powiadomienia, aby dowiedzieć się więcej.",
    "Could not find category \"%s\"" : "Nie można znaleźć kategorii \"%s\"",
    "Input text" : "Wprowadź tekst",
    "The input text" : "Wprowadzony tekst",
    "Sunday" : "Niedziela",
    "Monday" : "Poniedziałek",
    "Tuesday" : "Wtorek",
    "Wednesday" : "Środa",
    "Thursday" : "Czwartek",
    "Friday" : "Piątek",
    "Saturday" : "Sobota",
    "Sun." : "Nd.",
    "Mon." : "Pon.",
    "Tue." : "Wt.",
    "Wed." : "Śr.",
    "Thu." : "Czw.",
    "Fri." : "Pt.",
    "Sat." : "Sob.",
    "Su" : "Nd",
    "Mo" : "Pn",
    "Tu" : "Wt",
    "We" : "Śr",
    "Th" : "Czw",
    "Fr" : "Pt",
    "Sa" : "Sob",
    "January" : "Styczeń",
    "February" : "Luty",
    "March" : "Marzec",
    "April" : "Kwiecień",
    "May" : "Maj",
    "June" : "Czerwiec",
    "July" : "Lipiec",
    "August" : "Sierpień",
    "September" : "Wrzesień",
    "October" : "Październik",
    "November" : "Listopad",
    "December" : "Grudzień",
    "Jan." : "Sty.",
    "Feb." : "Lut.",
    "Mar." : "Mar.",
    "Apr." : "Kwi.",
    "May." : "Maj",
    "Jun." : "Cze.",
    "Jul." : "Lip.",
    "Aug." : "Sie.",
    "Sep." : "Wrz.",
    "Oct." : "Paź.",
    "Nov." : "Lis.",
    "Dec." : "Gru.",
    "A valid password must be provided" : "Należy podać prawidłowe hasło",
    "The Login is already being used" : "Login jest już używany",
    "Could not create account" : "Nie można utworzyć konta",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "W loginie dozwolone są tylko następujące znaki: „a-z”, „A-Z”, „0-9”, spacje i „_.@-'”",
    "A valid Login must be provided" : "Należy podać poprawny login",
    "Login contains whitespace at the beginning or at the end" : "Login zawiera spacje na początku lub na końcu",
    "Login must not consist of dots only" : "Login nie może składać się wyłącznie z kropek",
    "Login is invalid because files already exist for this user" : "Login jest nieprawidłowy, ponieważ dla tego użytkownika istnieją już pliki",
    "Account disabled" : "Konto wyłączone",
    "Login canceled by app" : "Logowanie anulowane przez aplikację",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Nie można zainstalować aplikacji \"%1$s\", ponieważ nie są spełnione następujące zależności: %2$s",
    "a safe home for all your data" : "bezpieczny dom dla wszystkich Twoich danych",
    "Application is not enabled" : "Aplikacja nie jest włączona",
    "Authentication error" : "Błąd uwierzytelniania",
    "Token expired. Please reload page." : "Token wygasł. Przeładuj stronę.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nie zainstalowano sterowników bazy danych (sqlite, mysql lub postgresql).",
    "Cannot write into \"config\" directory." : "Nie można zapisać do katalogu \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu config. Zobacz %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Jeśli, albo wolisz zachować plik config.php tylko do odczytu, ustaw w nim opcję \"config_is_read_only\" na true. Zobacz %s",
    "Cannot write into \"apps\" directory." : "Nie można zapisać do katalogu \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Zwykle można to naprawić, przyznając serwerowi WWW dostęp do zapisu do katalogu aplikacji lub wyłączając Nextcloud App Store w pliku konfiguracyjnym.",
    "Cannot create \"data\" directory." : "Nie można utworzyć katalogu \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Zwykle można to naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Uprawnienia można zazwyczaj naprawić, nadając serwerowi WWW dostęp do zapisu do katalogu głównego. Zobacz %s.",
    "Your data directory is not writable." : "Katalog danych nie jest zapisywalny.",
    "Setting locale to %s failed." : "Ustawienie języka na %s nie powiodło się.",
    "Please install one of these locales on your system and restart your web server." : "Zainstaluj jedną z lokalizacji w swoim systemie i ponownie uruchom serwer WWW.",
    "PHP module %s not installed." : "Moduł PHP %s nie jest zainstalowany.",
    "Please ask your server administrator to install the module." : "Poproś administratora serwera o zainstalowanie modułu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Ustawienie PHP \"%s\" nie jest ustawione na \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Dostosowanie tego ustawienia w php.ini spowoduje ponowne uruchomienie Nextcloud",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> jest ustawione na <code>%s</code> zamiast spodziewanej wartości <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Aby rozwiązać ten problem, ustaw <code>mbstring.func_overload</code> na <code>0</code> w pliku php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Wygląda na to, że PHP jest tak ustawione, aby wycinać bloki wklejonych dokumentów. Może to spowodować, że niektóre wbudowane aplikacje będą niedostępne.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Jest to prawdopodobnie spowodowane przez cache lub akcelerator, taki jak Zend OPcache lub eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Moduły PHP zostały zainstalowane, ale nadal brakuje ich na liście?",
    "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
    "The required %s config variable is not configured in the config.php file." : "Wymagana zmienna konfiguracyjna %s nie jest skonfigurowana w pliku config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Poproś administratora serwera o sprawdzenie konfiguracji Nextcloud.",
    "Your data directory is readable by other people." : "Twój katalog danych może być odczytywany przez inne osoby.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Zmień uprawnienia na 0770, aby katalog nie mógł być wyświetlany przez inne osoby.",
    "Your data directory must be an absolute path." : "Katalog danych musi mieć ścieżkę absolutną.",
    "Check the value of \"datadirectory\" in your configuration." : "Sprawdź wartość \"datadirectory\" w swojej konfiguracji.",
    "Your data directory is invalid." : "Katalog danych jest nieprawidłowy.",
    "Action \"%s\" not supported or implemented." : "Akcja \"%s\" jest niewspierana lub niezaimplementowana.",
    "Authentication failed, wrong token or provider ID given" : "Uwierzytelnienie nie powiodło się, podano nieprawidłowy token lub ID dostawcy",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Brak parametrów w celu uzupełnienia żądania. Brakujące parametry: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" jest już używany przez dostawcę chmury federacyjnej \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Dostawca Chmury Federacyjnej o ID: \"%s\" nie istnieje.",
    "Could not obtain lock type %d on \"%s\"." : "Nie można uzyskać blokady typu %d na \"%s\".",
    "Storage unauthorized. %s" : "Magazyn nieautoryzowany. %s",
    "Storage incomplete configuration. %s" : "Niekompletna konfiguracja magazynu. %s",
    "Storage connection error. %s" : "Błąd połączenia z magazynem. %s",
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage connection timeout. %s" : "Limit czasu połączenia do magazynu. %s",
    "Transcribe audio" : "Transkrypcja dźwięku",
    "Transcribe the things said in an audio" : "Transkrypcja wypowiedzi w formie audio",
    "Audio input" : "Wejście dźwięku",
    "The audio to transcribe" : "Dźwięk do transkrypcji",
    "Transcription" : "Transkrypcja",
    "The transcribed text" : "Tekst transkrypcji",
    "Confirmation" : "Potwierdzenie",
    "Generated response" : "Wygenerowana odpowiedź",
    "Writing style" : "Styl pisania",
    "Source material" : "Materiał źródłowy",
    "Describe the image you want to generate" : "Opisz obraz, który chcesz wygenerować",
    "Number of images" : "Liczba obrazów",
    "How many images to generate" : "Ile obrazów wygenerować",
    "Output images" : "Obrazy wyjściowe",
    "The generated images" : "Wygenerowane obrazy",
    "Change Tone" : "Zmień ton wypowiedzi",
    "Write a text that you want the assistant to rewrite in another tone." : "Napisz tekst, który chcesz, aby asystent napisał inaczej.",
    "Desired tone" : "Pożądany ton wypowiedzi",
    "In which tone should your text be rewritten?" : "W jakim tonie powinien zostać napisany Twój tekst?",
    "The rewritten text in the desired tone, written by the assistant:" : "Przepisany tekst w pożądanym tonie, napisany przez asystenta:",
    "Chat" : "Rozmowa",
    "Chat history" : "Historia rozmów",
    "Generates a possible headline for a text." : "Generuje możliwy nagłówek tekstu.",
    "Original text" : "Tekst oryginalny",
    "Text" : "Tekst",
    "Summarize" : "Podsumuj",
    "Summary" : "Podsumowanie",
    "Extract topics" : "Wyodrębnij tematy",
    "Topics" : "Tematy",
    "The list of extracted topics" : "Lista wyodrębnionych tematów",
    "Translate" : "Tłumaczenie",
    "Translate text from one language to another" : "Tłumaczenie tekstu z jednego języka na inny",
    "Origin text" : "Tekst źródłowy",
    "The text to translate" : "Tekst do przetłumaczenia",
    "Origin language" : "Język źródłowy",
    "The language of the origin text" : "Język tekstu źródłowego",
    "Target language" : "Język docelowy",
    "The desired language to translate the origin text in" : "Żądany język, na który ma zostać przetłumaczony tekst źródłowy",
    "Result" : "Wynik",
    "The translated text" : "Przetłumaczony tekst",
    "Free prompt" : "Monit bezpłatny",
    "Runs an arbitrary prompt through the language model." : "Uruchamia dowolny monit w modelu języka.",
    "Generate headline" : "Wygeneruj nagłówek",
    "Summarizes text by reducing its length without losing key information." : "Podsumowuje tekst, zmniejszając jego długość bez utraty kluczowych informacji.",
    "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
    "Education Edition" : "Edycja edukacyjna",
    "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
    "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
    "File name is too long" : "Nazwa pliku jest za długa",
    "Users" : "Użytkownicy",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s udostępnił Tobie »%2$s« i chce dodać: ",
    "%1$s shared »%2$s« with you and wants to add" : " %1$s udostępnił Tobie »%2$s« i chce dodać",
    "»%s« added a note to a file shared with you" : "»%s« dodał notatkę do udostępnionego dla Ciebie pliku",
    "Open »%s«" : "Otwórz »%s«",
    "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
    "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
    "File is currently busy, please try again later" : "Plik jest obecnie niedostępny, spróbuj później",
    "Cannot download file" : "Nie można pobrać pliku",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Upewnij się, że w katalogu \"data\" znajduje się plik o nazwie \".ocdata\"."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
